@@ -32,7 +32,7 @@ var opencl_8hpp =
     [ "cl::SVMAllocator< T, SVMTrait >", "classcl_1_1_s_v_m_allocator.html", "classcl_1_1_s_v_m_allocator" ],
     [ "cl::SVMAllocator< T, SVMTrait >::rebind< U >", "structcl_1_1_s_v_m_allocator_1_1rebind.html", null ],
     [ "cl::SVMAllocator< void, SVMTrait >", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4" ],
-    [ "cl::SVMAllocator< void, SVMTrait >::rebind< U >", "structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html", "structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind" ],
+    [ "cl::SVMAllocator< void, SVMTrait >::rebind< U >", "structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html", null ],
     [ "cl::detail::Deleter< Alloc >", "classcl_1_1detail_1_1_deleter.html", null ],
     [ "cl::Buffer", "classcl_1_1_buffer.html", "classcl_1_1_buffer" ],
     [ "cl::BufferGL", "classcl_1_1_buffer_g_l.html", "classcl_1_1_buffer_g_l" ],
@@ -62,22 +62,22 @@ var opencl_8hpp =
     [ "cl::EnqueueArgs", "classcl_1_1_enqueue_args.html", null ],
     [ "cl::KernelFunctor< Ts >", "classcl_1_1_kernel_functor.html", "classcl_1_1_kernel_functor" ],
     [ "cl::compatibility::make_kernel< Ts >", "structcl_1_1compatibility_1_1make__kernel.html", "structcl_1_1compatibility_1_1make__kernel" ],
-    [ "cl::atomic_svm_vector", "namespacecl.html#a445d7d2f4c3234dc5fbd2d254eb39e22", null ],
-    [ "cl::coarse_svm_vector", "namespacecl.html#a2903d8ce897eef7efca4ab6f32f2a197", null ],
-    [ "cl::fine_svm_vector", "namespacecl.html#a43fd451f30944f957126b167b4eb0664", null ],
-    [ "cl::allocate_pointer", "namespacecl.html#a8e1fce10cd1b8118f51aa91ce0a589e5", null ],
-    [ "cl::copy", "namespacecl.html#a05791e9d5da23b21abd6e319fb262c9f", null ],
-    [ "cl::copy", "namespacecl.html#a02c4368c6ce7a1a99132eafd5dc96fa9", null ],
-    [ "cl::copy", "namespacecl.html#a2f71ed9a316daf59c03c0f3ba62f1bd3", null ],
-    [ "cl::copy", "namespacecl.html#a1197a833cdd6664f206b079f2bebd2eb", null ],
-    [ "cl::enqueueMapSVM", "namespacecl.html#a640c02cb285c5ab57ab8669bc2146643", null ],
-    [ "cl::enqueueMapSVM", "namespacecl.html#a85686c89497c3ef296e3cf1840d7d725", null ],
-    [ "cl::enqueueMapSVM", "namespacecl.html#ae48b9857ac37b027d8e946f0cf3c3232", null ],
-    [ "cl::enqueueUnmapSVM", "namespacecl.html#a9835d1b49011a71e71b602c8b4db261e", null ],
-    [ "cl::enqueueUnmapSVM", "namespacecl.html#ab2784dad151e0aed0685067d190dc994", null ],
-    [ "cl::enqueueUnmapSVM", "namespacecl.html#ab76105928c721c5a922a4c1aea804e87", null ],
-    [ "cl::Local", "namespacecl.html#a2f9d06d8196d7a2f4cf196d5bb7e5dd0", null ],
-    [ "cl::mapSVM", "namespacecl.html#ae97dc5bb86e2c3c3935280a86cda301c", null ],
-    [ "cl::UnloadCompiler", "namespacecl.html#a2fc824c118740089633cc15e7107f3f0", null ],
-    [ "cl::unmapSVM", "namespacecl.html#af9f49b386b20c55c04a9e6cd21849fd5", null ]
+    [ "atomic_svm_vector", "opencl_8hpp.html#a445d7d2f4c3234dc5fbd2d254eb39e22", null ],
+    [ "coarse_svm_vector", "opencl_8hpp.html#a2903d8ce897eef7efca4ab6f32f2a197", null ],
+    [ "fine_svm_vector", "opencl_8hpp.html#a43fd451f30944f957126b167b4eb0664", null ],
+    [ "allocate_pointer", "opencl_8hpp.html#a8e1fce10cd1b8118f51aa91ce0a589e5", null ],
+    [ "copy", "opencl_8hpp.html#a05791e9d5da23b21abd6e319fb262c9f", null ],
+    [ "copy", "opencl_8hpp.html#a02c4368c6ce7a1a99132eafd5dc96fa9", null ],
+    [ "copy", "opencl_8hpp.html#a2f71ed9a316daf59c03c0f3ba62f1bd3", null ],
+    [ "copy", "opencl_8hpp.html#a1197a833cdd6664f206b079f2bebd2eb", null ],
+    [ "enqueueMapSVM", "opencl_8hpp.html#a640c02cb285c5ab57ab8669bc2146643", null ],
+    [ "enqueueMapSVM", "opencl_8hpp.html#a85686c89497c3ef296e3cf1840d7d725", null ],
+    [ "enqueueMapSVM", "opencl_8hpp.html#ae48b9857ac37b027d8e946f0cf3c3232", null ],
+    [ "enqueueUnmapSVM", "opencl_8hpp.html#a9835d1b49011a71e71b602c8b4db261e", null ],
+    [ "enqueueUnmapSVM", "opencl_8hpp.html#ab2784dad151e0aed0685067d190dc994", null ],
+    [ "enqueueUnmapSVM", "opencl_8hpp.html#ab76105928c721c5a922a4c1aea804e87", null ],
+    [ "Local", "opencl_8hpp.html#a2f9d06d8196d7a2f4cf196d5bb7e5dd0", null ],
+    [ "mapSVM", "opencl_8hpp.html#ae97dc5bb86e2c3c3935280a86cda301c", null ],
+    [ "UnloadCompiler", "opencl_8hpp.html#a2fc824c118740089633cc15e7107f3f0", null ],
+    [ "unmapSVM", "opencl_8hpp.html#af9f49b386b20c55c04a9e6cd21849fd5", null ]
 ];
\ No newline at end of file
